/* eslint-env node */
/* global module: false, process: false */
'use strict';

const defaultsDeep = require('lodash.defaultsdeep');

// 该常量用于监测当前运行环境是否为 'production'，某些配置选项会根据运行环境决定是否开启
const isProduction = process.env.EMBER_ENV === 'production';

module.exports = function foundation(options) {
  let defaults = {
    // @import 模块导入规则
    import: {
      path: ['node_modules/@choiceform/ui-foundation/addon/styles']
    },

    // CSS 变量
    variables: {
      // 主色
      '--primary':              '#2196F3',
      '--primary-darker':       '#0079C4',

      // 辅助色
      '--secondary':            '#4ECE3D',
      '--secondary-darker':     '#40B630',

      // 强调色
      '--accent':               '#373277',

      // 亮系主题色板
      '--palette-bright-01':    '#A8C6DF',
      '--palette-bright-02':    '#C5D9E8',
      '--palette-bright-03':    '#ECF5FD',
      '--palette-bright-04':    '#FAFBFC',

      // 暗色主题色板
      '--palette-dark-01':      '#212F40',
      '--palette-dark-02':      '#2C405A',
      '--palette-dark-03':      '#3F536E',
      '--palette-dark-04':      '#8DABC4',

      // 深色主体浅色背景
      // 主
      '--primary-text-dark':    '#3F536E',
      // 辅
      '--secondary-text-dark':  '#8DABC4',
      // 禁止／提示／图标
      '--disabled-text-dark':   '#A8C6DF',
      // 分割线
      '--divider-dark':         '#C5D9E8',

      // 浅色主体深色背景
      // 主
      '--primary-text-white':   '#ECF5FD',
      // 辅
      '--secondary-text-white': '#8DABC4',
      // 禁止／提示／图标
      '--disabled-text-white':  '#5b718c',
      // 分割线
      '--divider-white':        '#3F536E',

      // Colors
      '--midnight':             '#212F40',
      '--catalina-blue':        '#2C405A',
      '--fiord':                '#4B4B4B',
      '--nepal':                '#B3B3B3',
      '--botticelli':           '#CCCCCC',
      '--zumthor':              '#FAFBFC',
      '--white':                '#FFFFFF',
      '--black':                '#000000',

      // Active Colors
      '--cool-blue':            '#0093EE',
      '--dull-lime':            '#4ECE3D',
      '--ruddy':                '#FF151F',
      '--cool-blue-active':     '#0079C4',
      '--dull-lime-active':     '#40B630',

      // Branding Colors
      '--soft-purple':          '#AB7DF6',
      '--java':                 '#26C2C9',
      '--supernova':            '#FACA00',
      '--lime':                 '#81C926',
      '--pumpkin':              '#FD7B1F',

      // Typography
      '--font-size':            '1rem',
      '--font-bold':            '600',

      // Border Radius
      '--radius-small':         '2px',
      '--radius-medium':        '3px',
      '--radius-large':         '4px',
      '--radius-big':           'calc(var(--offset) / 2)',

      // Offset
      '--offset':               '2rem',

      // Z-index
      '--ui-dropdown':          '10',
      '--ui-popup':             'calc(var(--ui-dropdown) + 1)',
      '--ui-modal':             'calc(var(--ui-popup) + 1)',
      '--ui-loading':           'calc(var(--ui-modal) + 1)',
      '--ui-notification':      'calc(var(--ui-loading) + 1)',
    },

    // 保留原生 CSS 变量（高级浏览器支持）
    preserve: false,
  };

  options = defaultsDeep(options, defaults);
  let {preserve, variables} = options;

  return {
    // 本地模块化样式选项
    cssModules: {
      // PostCSS 选项
      postcssOptions: {
        // 使用 PostCSS 生成样式的 sourcemaps，用于浏览器内对应模块的跳转（推荐）
        map: !isProduction,
      },

      // PostCSS 插件，它们的选项在本文件的后半部分定义
      plugins: {
        // 作用于 CSS Modules 之前的
        before: [
          require('postcss-import')(options.import),
          require('postcss-nesting'),
          require('postcss-extend'),
          require('postcss-css-variables')({preserve, variables}),
        ],
        // 作用于 CSS Modules 之后的
        after: [
          require('postcss-merge-rules'),
          require('postcss-discard-empty'),
          require('postcss-discard-comments'),
          require('postcss-discard-duplicates'),
        ],
      },
    },

    /*
     * NPM Packages 导入管理选项
     *
     * 注意：请不要轻易修改这个对象，如果要禁用某些资源的加载，请修改随后对应的开关
     */
    nodeAssets: {
      // 导入 normalize.css 文件 - 是否编译取决于 useNormalizeCSS 选项的值（推荐）
      'normalize.css': function() {
        return {
          vendor: {include: ['normalize.css']},
          enabled: this.options.useNormalizeCSS,
        };
      },

      // 导入 device.css 文件 - 是否编译取决于 device.js 选项的值
      'device.js': function() {
        return {
          srcDir: 'lib',
          vendor: {include: ['device.js']},
          enabled: this.options.useDeviceJS,
        };
      },
    },

    // 是否默认包含 normalize.css 提供的样式（推荐）
    useNormalizeCSS: true,

    // 是否默认包含 device.js
    useDeviceJS: false,

    // 是否默认导入 SVG 图标
    importSVGIcon: true,

    // 是否将应用的环境选项作为 <meta> 标签注入到 HTML 文档中，否则编译到最终生成的 js 代码中
    storeConfigInMeta: false,
  }
};
